/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Employee.java 5369 2010-02-24 14:58:19Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.examples.entitybean;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;

/**
 * Define an employee with an id and a name.
 * @author Florent Benoit
 */
@Entity
@Table(name = "EMPLOYEES")
public class Employee implements java.io.Serializable {

    /**
     * Id for serializable class.
     */
    private static final long serialVersionUID = -2366200007462547454L;

    /**
     * Id of this employee.
     */
    private int id;

    /**
     * Name of the employee.
     */
    private String name;

    /**
     * Gets the Id of the employee.
     * @return the id of the employee.
     */
    @Id
    public int getId() {
        return id;
    }

    /**
     * Sets id of the employee.
     * @param id the id's employee
     */
    public void setId(final int id) {
        this.id = id;
    }

    /**
     * Sets the name.
     * @param name of employee.
     */
    public void setName(final String name) {
        this.name = name;
    }

    /**
     * Gets the name of the employee.
     * @return name of the employee.
     */
    public String getName() {
        return name;
    }

    /**
     * Computes a string representation of this employee.
     * @return string representation.
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("Employee[id=").append(getId()).append(", name=").append(getName()).append("]");
        return sb.toString();
    }

}
